  function [j]=julian(y,m,d,h)
% JULIAN: converts Gregorian calendar time to decimal Julian day.
% [j]=JULIAN(y,m,d,h) converts Gregorian calendar dates to corresponding
% Julian day numbers.  Although the formal definition holds that Julian 
% days start and end at noon, here Julian days start and end at midnight.
% In this convention, Julian day 2440000 began at 0000 UT, May 23, 1968.
% 
%   INPUT:  d -  day (1-31) component of Gregorian date
%           m -  month (1-12) component
%           y -  year (e.g., 1979) component
%           h -  UT decimal hours (assumed 0 if absent)
%   
%   OUTPUT: j - decimal Julian day number (e.g., 0000 UT Jan 1 is 0.0)
 
%   Usage:  [j]=julian(y,m,d) or julian([y,m,d]) with h==0
%              =julian(y,m,d,h) or julian([y,m,d,h])
%              =julian([y m d hr min sec])


% Adapted from JULIANMD in air_sea toolbox.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Version 1.0: 2/17/98
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
     
if nargin==3, h=0.; end;
if nargin==1, 
   [nr,nc]=size(y);
   if nc==3, h=0.; end;
   if nc==4, h=y(:,4); end;
   if nc==6, h=hms2h(y(:,4),y(:,5),y(:,6));end;
   d=y(:,3);
   m=y(:,2);
   y=y(:,1);
end


mo=m+9;
yr=y-1;
i=(m>2);
mo(i)=m(i)-3;
yr(i)=y(i); 
c = floor(yr/100);
yr = yr - c*100;
j = floor((146097*c)/4) + floor((1461*yr)/4) + ...
           floor((153*mo +2)/5) +d +1721119;


%     If you want Julian days to start and end at noon, 
%     replace the following line with:
%     j=j+(h-12)/24;
 
j=j+h/24;


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function [hours]=hms2h(h,m,s);
%HMS2H Converts hours, minutes, and seconds to hours.
%
%  Usage:  [hours]=hms2h(h,m,s);   or [hours]=hms2h(hhmmss);
%
if nargin== 1,
   hms=h;
   h=floor(hms/10000);
   ms=hms-h*10000;
   m=floor(ms/100);
   s=ms-m*100;
   hours=h+m/60+s/3600;
else
   hours=h+(m+s/60)/60;
end
